% ------------------------------------------------------------------------------
% Create configuration parameter lists of decoder names and NetCDF names.
%
% SYNTAX :
%  [o_decArgoConfParamNames, o_ncConfParamNames] = create_config_param_names_apx_argos(a_decoderId)
%
% INPUT PARAMETERS :
%    a_decoderId : decoder Id
%
% OUTPUT PARAMETERS :.
%    o_decArgoConfParamNames : internal configuration parameter names
%    o_ncConfParamNames      : NetCDF configuration parameter names
%
% EXAMPLES :
%
% SEE ALSO : 
% AUTHORS  : Jean-Philippe Rannou (Altran)(jean-philippe.rannou@altran.com)
% ------------------------------------------------------------------------------
% RELEASES :
%   07/10/2015 - RNU - creation
% ------------------------------------------------------------------------------
function [o_decArgoConfParamNames, o_ncConfParamNames] = create_config_param_names_apx_argos(a_decoderId)

% output parameters initialization
o_decArgoConfParamNames = [];
o_ncConfParamNames = [];

% current float WMO number
global g_decArgo_floatNum;

% output NetCDF configuration parameter Ids
global g_decArgo_outputNcConfParamId;

% output NetCDF configuration parameter labels
global g_decArgo_outputNcConfParamLabel;


% create configuration names for decoder and associated one for NetCDF
decConfNames = [];
ncConfNames = [];
switch (a_decoderId)
   
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case {1001, 1005, 1007, 1009, 1010, 1016}
      % 071412, 061810, 082213, 032213, 110613&090413, 090810
      
      configIds = [ ...
         {'UP'}, ...
         {'DOWN'}, ...
         {'PRKP'}, ...
         {'PPP'}, ...
         {'NUDGE'}, ...
         {'OK'}, ...
         {'ASCEND'}, ...
         {'TBP'}, ...
         {'TP'}, ...
         {'TPP'}, ...
         {'N'}, ...
         {'FEXT'}, ...
         {'FRET'}, ...
         {'IBN'}, ...
         {'CHR'}, ...
         {'PACT'}, ...
         {'DPDP'}, ...
         {'PDP'}, ...
         {'PRE'}, ...
         {'REP'}, ...
         {'TOD'}, ...
         {'DEBUG'}, ...
         {'DIR'}, ...
         {'CT'}, ...
         {'DPF'} ...
         ];

      for idC = 1:length(configIds)
         decConfNames{end+1} = sprintf('CONFIG_%s', configIds{idC});
         idParamName = find(strcmp(g_decArgo_outputNcConfParamId, decConfNames{end}) == 1);
         ncConfNames{end+1} = g_decArgo_outputNcConfParamLabel{idParamName};
      end
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case {1002, 1003, 1006} % 06208, 061609, 093008
      
      configIds = [ ...
         {'UP'}, ...
         {'DOWN'}, ...
         {'PRKP'}, ...
         {'PPP'}, ...
         {'NUDGE'}, ...
         {'OK'}, ...
         {'ASCEND'}, ...
         {'TBP'}, ...
         {'TP'}, ...
         {'TPP'}, ...
         {'N'}, ...
         {'FEXT'}, ...
         {'FRET'}, ...
         {'IBN'}, ...
         {'CHR'}, ...
         {'DPDP'}, ...
         {'PDP'}, ...
         {'PRE'}, ...
         {'REP'}, ...
         {'TOD'}, ...
         {'DEBUG'}, ...
         {'DIR'}, ...
         {'CT'}, ...
         {'DPF'} ...
         ];

      for idC = 1:length(configIds)
         decConfNames{end+1} = sprintf('CONFIG_%s', configIds{idC});
         idParamName = find(strcmp(g_decArgo_outputNcConfParamId, decConfNames{end}) == 1);
         ncConfNames{end+1} = g_decArgo_outputNcConfParamLabel{idParamName};
      end
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case {1004} % 021009
      
      configIds = [ ...
         {'ASCEND'}, ...
         {'CT'}, ...
         {'DEBUG'}, ...
         {'DIR'}, ...
         {'DOWN'}, ...
         {'DPDP'}, ...
         {'DPF'}, ...
         {'FEXT'}, ...
         {'FRET'}, ...
         {'IBN'}, ...
         {'ICEM'}, ...
         {'IMLT'}, ...
         {'N'}, ...
         {'NUDGE'}, ...
         {'OK'}, ...
         {'PDP'}, ...
         {'PPP'}, ...
         {'PRE'}, ...
         {'PRKP'}, ...
         {'REP'}, ...
         {'TBP'}, ...
         {'TOD'}, ...
         {'TP'}, ...
         {'TPP'}, ...
         {'UP'} ...
         ];

      for idC = 1:length(configIds)
         decConfNames{end+1} = sprintf('CONFIG_%s', configIds{idC});
         idParamName = find(strcmp(g_decArgo_outputNcConfParamId, decConfNames{end}) == 1);
         ncConfNames{end+1} = g_decArgo_outputNcConfParamLabel{idParamName};
      end
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case {1008, 1013, 1014} % 021208, 071807, 082807
      
      configIds = [ ...
         {'ASCEND'}, ...
         {'CT'}, ...
         {'DEBUG'}, ...
         {'DIR'}, ...
         {'DOWN'}, ...
         {'DPDP'}, ...
         {'DPF'}, ...
         {'FEXT'}, ...
         {'FRET'}, ...
         {'IBN'}, ...
         {'N'}, ...
         {'NUDGE'}, ...
         {'OK'}, ...
         {'PDP'}, ...
         {'PPP'}, ...
         {'PRE'}, ...
         {'PRKP'}, ...
         {'REP'}, ...
         {'TBP'}, ...
         {'TOD'}, ...
         {'TP'}, ...
         {'TPP'}, ...
         {'UP'} ...
         ];

      for idC = 1:length(configIds)
         decConfNames{end+1} = sprintf('CONFIG_%s', configIds{idC});
         idParamName = find(strcmp(g_decArgo_outputNcConfParamId, decConfNames{end}) == 1);
         ncConfNames{end+1} = g_decArgo_outputNcConfParamLabel{idParamName};
      end
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case {1015} % 020110
      
      configIds = [ ...
         {'ASCEND'}, ...
         {'CT'}, ...
         {'DEBUG'}, ...
         {'DIR'}, ...
         {'DOWN'}, ...
         {'DPDP'}, ...
         {'DPF'}, ...
         {'FEXT'}, ...
         {'FRET'}, ...
         {'IBN'}, ...
         {'N'}, ...
         {'NUDGE'}, ...
         {'OK'}, ...
         {'PDP'}, ...
         {'PPP'}, ...
         {'PRE'}, ...
         {'PRKP'}, ...
         {'REP'}, ...
         {'TBP'}, ...
         {'TOD'}, ...
         {'TP'}, ...
         {'TPP'}, ...
         {'UP'}, ...
         {'X01'}, ...
         {'X02'}, ...
         {'X03'}, ...
         {'X04'}, ...
         {'X05'}, ...
         {'X06'}, ...
         {'X07'}, ...
         {'X08'} ...
         ];

      for idC = 1:length(configIds)
         decConfNames{end+1} = sprintf('CONFIG_%s', configIds{idC});
         idParamName = find(strcmp(g_decArgo_outputNcConfParamId, decConfNames{end}) == 1);
         ncConfNames{end+1} = g_decArgo_outputNcConfParamLabel{idParamName};
      end
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case {1011, 1012} % 121512, 110813
      
      configIds = [ ...
         {'ASCEND'}, ...
         {'CT'}, ...
         {'DEBUG'}, ...
         {'DIR'}, ...
         {'DOWN'}, ...
         {'DPDP'}, ...
         {'DPF'}, ...
         {'FEXT'}, ...
         {'FRET'}, ...
         {'IBN'}, ...
         {'ICEM'}, ...
         {'IDP'}, ...
         {'IEP'}, ...
         {'IMLT'}, ...
         {'N'}, ...
         {'NUDGE'}, ...
         {'OK'}, ...
         {'PDP'}, ...
         {'PPP'}, ...
         {'PRE'}, ...
         {'PRKP'}, ...
         {'REP'}, ...
         {'TBP'}, ...
         {'TOD'}, ...
         {'PACT'}, ...
         {'TP'}, ...
         {'TPP'}, ...
         {'UP'} ...
         ];

      for idC = 1:length(configIds)
         decConfNames{end+1} = sprintf('CONFIG_%s', configIds{idC});
         idParamName = find(strcmp(g_decArgo_outputNcConfParamId, decConfNames{end}) == 1);
         ncConfNames{end+1} = g_decArgo_outputNcConfParamLabel{idParamName};
      end
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case {1021} % 2.8.0.A
      
      configIds = [ ...
         {'DIR'}, ...
         {'CT'}, ...
         {'ARM'}, ...
         {'AR'}, ...
         {'TOD'}, ...
         {'ASCEND'}, ...
         {'ATI'}, ...
         {'NUDGE'}, ...
         {'TPP'}, ...
         {'TP'}, ...
         {'DPDP'}, ...
         {'DDTI'}, ...
         {'DPF'}, ...
         {'DOWN'}, ...
         {'ETI'}, ...
         {'IBD'}, ...
         {'IMLT'}, ...
         {'IDP'}, ...
         {'IEP'}, ...
         {'ICEM'}, ...
         {'ITI'}, ...
         {'IBN'}, ...
         {'LD'}, ...
         {'DEBUG'}, ...
         {'PACT'}, ...
         {'MAP'}, ...
         {'MBC'}, ...
         {'OK'}, ...
         {'PBN'}, ...
         {'PDB'}, ...
         {'PPP'}, ...
         {'PDP'}, ...
         {'PDTI'}, ...
         {'PRKP'}, ...
         {'PTI'}, ...
         {'N'}, ...
         {'PST'}, ...
         {'PRE'}, ...
         {'SPSPC'}, ...
         {'REP'}, ...
         {'UP'}, ...
         {'VM'}, ...
         {'TBP'}, ...
         {'FRET'}, ...
         {'FEXT'} ...
         {'SAMPLE01'} ...
         {'SAMPLE02'} ...
         {'SAMPLE03'} ...
         {'SAMPLE04'} ...
         {'SAMPLE05'} ...
         {'SAMPLE06'} ...
         ];

      for idC = 1:length(configIds)
         decConfNames{end+1} = sprintf('CONFIG_%s', configIds{idC});
         idParamName = find(strcmp(g_decArgo_outputNcConfParamId, decConfNames{end}) == 1);
         ncConfNames{end+1} = g_decArgo_outputNcConfParamLabel{idParamName};
      end
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case {1022} % 2.10.4.A
      
      configIds = [ ...
         {'DIR'}, ...
         {'CT'}, ...
         {'ARM'}, ...
         {'AR'}, ...
         {'TOD'}, ...
         {'ASCEND'}, ...
         {'ATI'}, ...
         {'NUDGE'}, ...
         {'TPP'}, ...
         {'TP'}, ...
         {'DPDP'}, ...
         {'DDTI'}, ...
         {'DPF'}, ...
         {'DOWN'}, ...
         {'ETI'}, ...
         {'HRC'}, ...
         {'HRP'}, ...
         {'IBD'}, ...
         {'IMLT'}, ...
         {'IDP'}, ...
         {'IEP'}, ...
         {'ICEM'}, ...
         {'ITI'}, ...
         {'IBN'}, ...
         {'LD'}, ...
         {'DEBUG'}, ...
         {'PACT'}, ...
         {'MAP'}, ...
         {'MBC'}, ...
         {'OK'}, ...
         {'PBN'}, ...
         {'PDB'}, ...
         {'PPP'}, ...
         {'PDP'}, ...
         {'PDTI'}, ...
         {'PRKP'}, ...
         {'PTI'}, ...
         {'N'}, ...
         {'PST'}, ...
         {'PRE'}, ...
         {'SPSPC'}, ...
         {'REP'}, ...
         {'UP'}, ...
         {'VM'}, ...
         {'TBP'}, ...
         {'FRET'}, ...
         {'FEXT'} ...
         {'SAMPLE01'} ...
         {'SAMPLE02'} ...
         {'SAMPLE03'} ...
         {'SAMPLE04'} ...
         {'SAMPLE05'} ...
         {'SAMPLE06'} ...
         ];

      for idC = 1:length(configIds)
         decConfNames{end+1} = sprintf('CONFIG_%s', configIds{idC});
         idParamName = find(strcmp(g_decArgo_outputNcConfParamId, decConfNames{end}) == 1);
         ncConfNames{end+1} = g_decArgo_outputNcConfParamLabel{idParamName};
      end
      
   otherwise
      fprintf('WARNING: Float #%d: Nothing implemented yet for decoderId #%d\n', ...
         g_decArgo_floatNum, ...
         a_decoderId);
end

% output for check
% for id = 1:length(decConfNames)
%    fprintf('%s;%s\n', decConfNames{id}, ncConfNames{id});
% end

% update output parameters
o_decArgoConfParamNames = decConfNames;
o_ncConfParamNames = ncConfNames;

return
